*------------------------------------------------------------------------------
*- Version....: Sage Pro ERP 2010
*- File Name..: $Workfile: DUMPVCX.PRG $
*- VCS Level..: $Revision: 1 $
*- Last Update: $Date: 8/14/08 9:18p $
*------------------------------------------------------------------------------
*- Copyright (C) 2009 Sage Software, Inc.  All Rights Reserved.
*------------------------------------------------------------------------------
*- App ID.....: TOOLS
*- App Name...: Development tools
*------------------------------------------------------------------------------
*- Synopsis...: This programs dumps the method code and properties of a class 
*-              into a text file enabling you to compare.
*- 
*-              If you pass the input and output files it converts the input 
*-              files to the given output file.  
*-              If no parameters are passed it lets you pickup the input files
*-              and creates an output file with the same name.
*------------------------------------------------------------------------------
*- Called By..: Command prompt or other tool
*------------------------------------------------------------------------------
*- Parameters.: pc_InFile,  The class library  (Ex: C:\pro65\po\porecp.vcx)
*-              pc_OutFile, The Name of output file
*-              pl_Silent,  Run in silent mode.
*-              pc_Class,   [Optional] Dump source only for specific class
*------------------------------------------------------------------------------
LPARAMETERS pc_InFile, ;
            pc_OutFile, ;
            pl_Silent, ;
            pc_Class

#define Cc_OsEol CHR(13) + CHR(10)

LOCAL ll_cont, ;
      lc_InFile, ;
      lc_OutFile, ;
      lc_Class

ll_cont = .t.

IF NOT EMPTY(pc_Class)
  lc_Class = ALLTRIM(LOWER(pc_Class))
ELSE
  lc_Class = ""
ENDIF

*--Add path, VCX etc. to the source if not passed
IF TYPE("pc_InFile") = "C" 
  lc_InFile = UPPER(ALLTRIM(pc_InFile))
  lc_InFile = lc_InFile + IIF(AT("VCX", lc_InFile)=0, ".VCX", "")
  lc_InFile = IIF(AT(":", lc_InFile)=0, FULLPATH(""), "") + lc_InFile
  lc_InFile = STRTRAN(lc_InFile, "\\", "\")
ENDIF

*--Get the source if not passed
IF TYPE("lc_InFile") = "C" AND FILE(lc_InFile)
  lc_InFile = UPPER(lc_InFile)
ELSE
  lc_InFile =GETFILE("VCX", "Please select the class library (.VCX) to convert", "", 0, "Convert classes to text file")
ENDIF

ll_cont = FILE(lc_InFile)

IF ll_cont
  *-- Populate an output file if not passed
  lc_OutFile = IIF(TYPE("pc_OutFile") = "C", pc_OutFile, STRTRAN(lc_InFile, "VCX", "TXT"))

  SELECT 0
  USE (lc_InFile) ALIAS a_class
  SELECT a_class
  INDEX ON LEFT(UPPER(ALLTRIM(parent) + ALLTRIM(objname)),100) TO temp ;
    FOR !empty(objname) AND !DELETED()

  IF NOT EMPTY(lc_Class)
    *-- Filter for the particular class and the objects in that class
    SET FILTER TO (objname == pc_Class AND EMPTY(Parent)) OR ;
      (LEFT(Parent, LEN(pc_Class + ".")) = pc_Class + ".")
  ENDIF
     
  SET ORDER TO temp
  lc_text = ""

  SCAN

    IF NOT pl_Silent
      WAIT WINDOW "Converting " + lc_InFile + " to "  + lc_OutFile + "." NOWAIT
    ENDIF

    lc_Text = lc_Text + Cc_OsEol + ;
              "Class/Object: " + objname + Cc_OsEol + ;
              "************** PROPERTIES *************** " + Cc_OsEol  + ;
              properties + Cc_OsEol  + ;
              "************** METHODS ****************** " + Cc_OsEol  + ;
              IIF(EMPTY(methods), "", l_ArrangeMethods(methods)) + Cc_OsEol 
  ENDSCAN

  STRTOFILE(lc_text, lc_OutFile)

  IF NOT pl_Silent
    WAIT WINDOW "***  Done  *** " NOWAIT
  ENDIF

  IF USED("a_Class")
    USE IN a_Class
  ENDIF

ENDIF

IF ll_cont AND NOT pl_Silent AND ;
  FILE(lc_OutFile)

  IF EMPTY(pc_OutFile) AND ;
     MESSAGEBOX("Do you want to view " + lc_OutFile + ".",4) = 6

     MODIFY COMMAND (lc_OutFile)
  ENDIF

ENDIF

RETURN lc_OutFile 

*-------------------------------------------------------------------------------
*- Method.....: l_ArrangeMethods
*-------------------------------------------------------------------------------
*- Synopsis...: Function to arrange method code in alphabetical order of 
*-              method name
*-------------------------------------------------------------------------------
*- Parameters.: pc_Methods, The methods' code (normally from the memo field)
*-------------------------------------------------------------------------------
*- Returns:
*- Value......: lc_Return, Methods arranged in alphabetical order
*-------------------------------------------------------------------------------
FUNCTION l_ArrangeMethods

LPARAMETERS pc_Methods

  LOCAL lc_meth, ;
        ln_times
  
  lc_return = ""
  
  CREATE CURSOR ac_temp (MethName C(200), MethSnip M(4))

  FOR ln_times=1 TO OCCURS("ENDPROC", pc_methods)
    SELECT ac_temp
    APPEND BLANK 
    
    IF ln_times = 1
      REPLACE MethSnip WITH "PROCEDURE " + ;
                            STREXTRACT(pc_Methods, "PROCEDURE ", "ENDPROC", ln_times) + ;
                            "ENDPROC"
    ELSE
      REPLACE MethSnip WITH "PROCEDURE " + ;
                            STREXTRACT(pc_Methods, Cc_OsEol + "PROCEDURE ", "ENDPROC", ln_times-1) + ;
                            "ENDPROC"
    ENDIF
    
    REPLACE MethName WITH UPPER(GETWORDNUM(STRTRAN(MethSnip, "PROCEDURE "), 1, Cc_OsEol))
  NEXT
  
  INDEX ON MethName TAG MethName
  SET ORDER TO MethName

  SCAN
    lc_return = lc_return + Cc_OsEol + MethSnip + Cc_OsEol
  ENDSCAN

  IF USED("ac_temp")
    USE IN ac_temp
  ENDIF

RETURN lc_return 
