*------------------------------------------------------------------------------
*- Version....: Sage Pro ERP 2010
*- File Name..: $Workfile: PROLOADAPP.PRG $
*- VCS Level..: $Revision: 1 $
*- Last Update: $Date: 8/14/08 9:18p $
*------------------------------------------------------------------------------
*- Copyright (C) 2009 Sage Software, Inc.  All Rights Reserved.
*------------------------------------------------------------------------------
*- Description: Loads pro for an application & company in non visual mode 
*------------------------------------------------------------------------------
*- Synopsis...: Brings up the pro application in non visual mode. 
*-              Logs in to pro as ADMN.
*-              Instantiates all global objects required by pro and the 
*-              application object.
*------------------------------------------------------------------------------
*- Parameters.: pc_ApplId, Application id (Required)
*-              pc_CompId, Company id (Optional)
*-              ll_ShowMenu, .t. to show the pro menu
*-                           .f. will only load the appln object
*------------------------------------------------------------------------------
*- Example:     
*-     DO Tools\ProLoadApp WITH "AP", "99", .t.
*------------------------------------------------------------------------------
LPARAMETERS pc_Applid, ;
            pc_Compid, ;
            pl_ShowMenu

*-- Include global constants
#include global.h
#include events.h
#include helpid.h
#include windows.h

IF TYPE("go_Cop") == "O" AND TYPE("go_Sql")== "O" AND TYPE("go_pro") == "O"
  *-- When user try to rerun this tool,
  *-- Display alert
  DO g_dspalt WITH "Pro is already running on this system.", 3
  RETURN TO MASTER
ENDIF

*-- Declare public variables
RELEASE go_Api, ;
        go_Globals, ;
        go_Cop, ;
        go_Error, ;
        go_Sql, ;
        gl_Visual, ;
        gc_dbcname, ;
        gl_Debug, ;
        gl_DUtil, ;
        gl_trial, ;
        gc_glob, ;
        gl_rbInstalled, ;
        gl_rbEnabled, ;
        gl_rbMode, ;
        gl_rbLinkON, ;
        ll_SelApp, ;
        go_Pro

PUBLIC go_Pro, ;
       go_Sql, ;
       go_Api, ;
       go_Cop, ;
       go_Globals, ;
       go_Error, ;
       gl_Visual, ;
       gc_dbcname, ;
       gl_Debug, ;
       gl_DUtil, ;
       gl_trial, ;
       gc_glob, ;
       gl_rbInstalled, ;
       gl_rbEnabled, ;
       gl_rbMode, ;
       gl_rbLinkON, ;
       ll_SelApp

LOCAL lc_Applid, ;
      lc_Compid, ;
      ll_Return

*-- Initialize variable
lc_Applid = ""
lc_CompID = ""
ll_Return = .t.

*-- Validate parameters
IF TYPE("pc_Applid") == "C" AND NOT EMPTY(pc_Applid)
  lc_Applid = UPPER(pc_Applid)
ELSE

  lc_Msg = "Parameters: " + CHR(10) + CHR(13) + ;
           "pc_Applid, Application ID (Required)" + CHR(10) + CHR(13) + ;
           "pc_Compid, Company ID (Optional)" + CHR(10) + CHR(13) + ;
           "pl_Showmenu, ShowMenu (Optional)"

  MESSAGEBOX(lc_Msg, 64)
  RETURN TO MASTER

ENDIF

IF TYPE("pc_compid") == "C"
  lc_Compid = UPPER(pc_Compid)
ELSE
  lc_Compid = ""
ENDIF

*-- Set data base name
gc_dbcname = "PRODATA"
gl_debug   = .f.

*-- Instantiate pro component (defined at pro.prg file)
go_Pro = NEWOBJECT("sbtcmpPro", "pro.prg")

ll_Return = go_Pro.m_Init(Cn_ProNonVisualCOM, "pro.ini")

*-- Property added for menu
ADDPROPERTY(go_Pro, "sl_ShowMenu", pl_ShowMenu)

*-- Set visual 
RELEASE gl_Visual
PUBLIC gl_Visual

gl_Visual = .t.

*-- Recall to set environment
ll_Return = go_Pro.m_SetBaseEnvironment("Pro.ini")

*-- Login as non visual mode
gl_Visual = .f.
ll_Return = ll_Return AND go_Pro.m_Login("ADMN", "ADMN")

*-- clear screen
CLEAR 

*-- Reset to visual mode
gl_Visual = .t.

*-- Setup locale-specific information for installation
DO c_setlo WITH (gc_loclid), .f.

*-- Init timer events
go_Cop.NewObject("cmpPollingTimer", "sbtcmpPollingTimer", "pro.prg", "")
go_Cop.NewObject("cmpNewMsgTimer",  "sbtcmpNewMsgTimer",  "pro.prg", "")

*-- Setup instalation drive informations
DO c_Setin

*# DOCCODE DO sbthelp.mpr
DO (gc_idrvdbf + "sbtmenu.mpr")

*# DOCCODE DO sbthelp.mpr
DO (gc_idrvdbf + "sbthelp.mpr")

*-- Activate menu
STORE 0 TO lb_tbbrow, ;
           lb_tbstat, ;
           lb_tbtech, ;
           lb_tbuser, ;
           lb_tbdebug, ;
           lb_tbcalc, ;
           lb_tbmesg, ;
           lb_tbexit, ;
           lb_tbhelp

= WASMOUSE(.f.)

*# DOCCODE DO sbttbar.prg
DO sbttbar.prg

*-- remove tool bar
IF TYPE("Objsbttbar.Baseclass") == "C" AND NOT pl_ShowMenu
  Objsbttbar.Visible = .f.
ENDIF

IF TYPE("Objsbttbar.Baseclass") == "C" AND NOT Pl_ShowMenu
  Objsbttbar.Visible = .f.
ENDIF

*-- Load selected application
ll_Return = l_GetApplication (lc_Applid, lc_CompID)

IF ll_Return 

  *-- Set application is selected
  ll_SelApp = .t.

  *-- Set total application count
  gn_fstbar = 18

  IF TYPE("Objsbttbar.Baseclass") == "C"
    Objsbttbar.m_Refresh()
  ENDIF

  IF NOT pl_ShowMenu

    *-- Remove application menu
    DO l_ClearMenu

  ELSE
    *-- Get selected application
    ACTIVATE SCREEN 

  ENDIF

ENDIF  && ll_Return

IF NOT ll_Return
  *-- Call clean up
  DO l_CleanUp
ENDIF

RETURN

*------------------------------------------------------------------------------
*- Method.....: l_GetApplication
*------------------------------------------------------------------------------
*- Synopsis...: Returns an application object (currently just sets one up)
*------------------------------------------------------------------------------
*- Parameters.: pc_CompId, company ID
*-              pc_ApplId, application ID
*------------------------------------------------------------------------------
*- Returns:
*- Value......: ll_Return, true if application attached
*------------------------------------------------------------------------------
FUNCTION l_GetApplication

LPARAMETERS pc_Applid, ;
            pc_Compid

  PRIVATE lc_Applid,  ;
          lc_CompID,  ;
          lc_Descrip 

  LOCAL ln_DataSession, ;
        ll_Return, ;
        lc_appwt, ;
        lc_adrvprg, ;
        ln_OpnSycdat, ;
        ln_OpnSydapp

  *-- Initialise locals
  lc_ApplID = pc_Applid
  lc_CompID = pc_CompID
  ll_Return = .t.

  ln_OpnSycdat = 0
  ln_OpnSydapp = 0

  *-- Store current datasession
  ln_DataSession = SET("Datasession")

  *-- Set the current datasession to 1 as the data session does not change in cases
  *-- like modal MDI forms being open
  SET DATASESSION TO 1

  *-- Desable hot keys before application load
  = g_sethk(.f.)

  *-- Get selected application description 
  lc_Descrip = UPPER(d_retap(IIF(lc_ApplId = "SM", "SY", lc_ApplId), 1))

  IF EMPTY(lc_Descrip)
    *-- Display alert
    DO g_dspalt WITH "Startup program " + lc_applid + ;
                     " is missing.  Please check the" + ;
                     gc_oseol + "installation in System Manager " + ;
                     "before proceeding.", 3
    ll_Return = .f.
  ENDIF

  IF ll_Return
    *-- Verify application installed
    *-- Display message
    DO g_dspst WITH "Checking application...", .t., gn_msgline, ;
                    Cc_NullStr, Cc_NullStr, Cc_NullStr

    *-- Open the application file
    ln_OpnSydapp = g_opnfl(gc_idrvdbf + "sydappl", "a_sydapp" , .f., .f., ;
              Cc_NullStr)

    *-- Get application id
    go_SQL.so_CurrentAlias.m_Locate("FOR " + ;
        "UPPER(a_sydapp.descrip) = ??lc_Descrip")

    lc_applid = a_sydapp->applid
    lc_appwt  = a_sydapp->descrip

    *-- Open installed applications file
    ln_OpnSycdat = g_opnfl(gc_idrvdbf + "sycdata", "a_sycdat", .f., .f., ;
                          "applid1")

    IF EMPTY(lc_compid) OR INLIST(lc_Applid, "SM", "SY", "CU")
      *-- Get first company installed for this application
      go_SQL.so_CurrentAlias.m_Seek(lc_applid, "")
    ELSE
      go_SQL.so_CurrentAlias.m_Seek(lc_applid + lc_compid, "")
    ENDIF

    *-- If the installation record found or there is no record
    *-- for this application
    *-- Logical datatype Change - For DB2
    IF go_SQL.so_CurrentAlias.m_IsFound() OR (a_sydapp.noappchk = gx_True) ;
                  OR INLIST(lc_Applid, "SM", "SY", "CU")

      *-- Set the compid to object
      go_Pro.sc_Compid = a_sycdat->compid

      gc_Compid = go_Pro.sc_Compid

      IF (a_sydapp->noappchk = gx_True)
        *-- Take the application path from SM path by replacing SM
        *-- with application id
        lc_adrvprg  = STRTRAN(gc_idrvprg, "\SM", "\" + lc_applid)
      ELSE
        *-- Application program path
        lc_adrvprg  = ALLTRIM(a_sycdat->adosprg)

      ENDIF
    
      IF lc_Applid = "SY"
        *-- Check for startup program
        IF NOT gl_Visual AND NOT ;
           (FILE(gc_idrvprg + "sm.prg") OR ;
           FILE(gc_idrvprg + "sm.fxp") OR ;
           FILE(gc_idrvprg + "sm.app"))

          *-- Display alert
          DO g_dspalt WITH "Startup program SM" + ;
                           ".PRG/FXP is missing.  Please check the" + ;
                           gc_oseol + "installation in System Manager " + ;
                           "before proceeding.", 3

          *-- Quit program
          DO g_extos 
        ENDIF

      ELSE

        *-- If startup program not found
        IF gl_Visual AND ;
           NOT FILE(lc_adrvprg + lc_applid + ".prg") AND NOT ;
           FILE(lc_adrvprg + lc_applid + ".fxp") AND NOT ;
           FILE(lc_adrvprg + lc_applid + ".app")

          *-- Display alert
          DO g_dspalt WITH "Startup program " + lc_applid + ;
                           ".PRG/FXP is missing.  Please check the" + ;
                           gc_oseol + "installation in System Manager " + ;
                           "before proceeding.", 3

          *-- Quit program
          DO g_extos
        ENDIF

      ENDIF

    ELSE
      *-- Display alert
      DO g_dspalt WITH "Startup company " + lc_compid + ;
                       " is missing.  Please check the" + ;
                       gc_oseol + "installation in System Manager " + ;
                       "before proceeding.", 3
      ll_Return = .f.
    ENDIF

  ENDIF && ll_Return

  IF ll_Return 

    *-- Set process id for privilege checking
    gc_procid = lc_applid

    IF lc_Applid = "SY"

      *-- Call SM initialization
      *# DOCCODE DO sm
      gc_procid = "SM"

      DO (gc_idrvprg + "sm") WITH Cc_NullStr, ".INIT", 0

      MODIFY WINDOW SCREEN ;
                  TITLE "ACCPAC Pro Series - System Manager"
    ELSE
      *-- Other than system manager applications
      DO (lc_adrvprg + lc_applid) WITH Cc_NullStr, ".INIT", 0

      MODIFY WINDOW SCREEN ;
                 TITLE "ACCPAC Pro Series - " + ALLTRIM(lc_appwt)
    ENDIF

    *-- set applid
    go_Pro.sc_Applid = lc_applid

    *-- Open system/cu files
    DO g_opnsys

    IF gc_applid = "SM"
      gc_MenuApplid = gc_Applid
    ENDIF    

    IF NOT EMPTY(gc_MenuApplid)
      *-- Re-Instantiate the global object for
      *-- the currently selected application
      = go_Globals.m_ResetObject(gc_MenuApplid, gc_compid)
    ENDIF

  ENDIF 

  *-- Close the tables if opened here
  IF ln_OpnSydapp = 2 AND go_SQL.m_IsUsed("a_sydapp")
      go_SQL.m_CloseTable("a_sydapp")
  ENDIF

  IF ln_OpnSycdat = 2 AND go_SQL.m_IsUsed("a_sycdat")
    go_SQL.cmpA_Sycdat.m_CloseTable()
  ENDIF

  *-- Enable hot keys after changing application
  = g_sethk(.t.)

  *-- Assign go_cop properties for applid and compid (for standard toolbar)
  go_cop.sc_sbarapplid = gc_MenuApplid
  go_cop.sc_sbarcompid = gc_compid

  *-- Restore datasession
  SET DATASESSION TO &ln_DataSession.

RETURN ll_Return 
*------------------------------------------------------------------------------
*- End Procedure...: l_GetApplication
*------------------------------------------------------------------------------

*------------------------------------------------------------------------------
*- Method      : l_ClearMenu
*------------------------------------------------------------------------------
*- Description : Remove the current application menu pads
*------------------------------------------------------------------------------
PROCEDURE l_ClearMenu

LPARAMETERS pl_EraseFile

  LOCAL lc_UserMpr, ;
        lc_RelMpr, ;
        lc_Temp

  *-- Remove the menu pads defined for the currently loaded
  *-- application before generating the new menu definition code
  lc_UserMpr = go_Cop.sc_MenuFile

  IF NOT EMPTY(lc_UserMpr)
    *-- Get the file name of the pads releasing MPR
    lc_RelMpr  = STRTRAN(lc_UserMpr, ".MPR", "RL.MPR")

    IF FILE(lc_RelMpr)
      *-- Compile the pads releasing MPR before executing it
      lc_temp = lc_RelMpr
      lc_temp = STRTRAN(UPPER(lc_temp), "." + JUSTEXT(lc_temp), ".MPX")
      DO &lc_temp.

      IF pl_EraseFile
        *-- Erase the Menu definition and pads releasing MPR files
        lc_UserMpr = STRTRAN(lc_UserMpr, ".MPR", ".*")
        lc_RelMpr  = STRTRAN(lc_RelMpr, ".MPR", ".*")
        ERASE (lc_UserMpr)
        ERASE (lc_RelMpr)

        *-- Reset the file extension for conventional menu mpr file name
        lc_UserMpr = FORCEEXT(lc_UserMpr, "MPR")

      ENDIF

      *-- set system menu
      SET SYSMENU AUTOMATIC
      ACTIVATE SCREEN
    ENDIF

  ENDIF  && NOT EMPTY(lc_UserMpr)

RETURN
*------------------------------------------------------------------------------
*- End Procedure...: l_Clearmenu
*------------------------------------------------------------------------------

*------------------------------------------------------------------------------
*- Method      : l_CleanUp
*------------------------------------------------------------------------------
*- Description : Remove all pro objects
*------------------------------------------------------------------------------
PROCEDURE l_CleanUp

  *-- Quit Pro application
  DO g_extap

  *-- Return to Foxpro
  RETURN TO MASTER

RETURN
*------------------------------------------------------------------------------
*- End Procedure...: l_Cleanup
*------------------------------------------------------------------------------
