*------------------------------------------------------------------------------
*- Version....: Sage Pro ERP 2010
*- File Name..: $Workfile: UPLOAD.PRG $
*- VCS Level..: $Revision: 1 $
*- Last Update: $Date: 8/14/08 9:18p $
*------------------------------------------------------------------------------
*- Copyright (C) 2009 Sage Software, Inc.  All Rights Reserved.
*------------------------------------------------------------------------------
*- App ID.....: SY
*- App Name...: Tools
*------------------------------------------------------------------------------
*- Synopsis...: Uploads a VFP system table to SQL server/db2
*-              Useful if modifying system data (like data dictionary)
*-              and then want to check if it works in SQL server.
*-
*-              NOTE: You must have a valid go_Sql object before running the tool
*------------------------------------------------------------------------------
*- Parameters.: pc_TableToUpload, Pass the table name (w/ path and w/o extension)
*-              pl_Silent, [Optional] Set to .t. to avoid warnings. 
*-                         Will still put up dialog for errors.
*-              pc_Compid, [Optional] Pass this if the company you want to
*-                                    upload is different from the company
*-                                    number given in the pc_TableToUpload
*-                                    Ignored if table is a system table.
*------------------------------------------------------------------------------
*- Called By..: Command Window
*------------------------------------------------------------------------------
LPARAMETERS pc_TableToUpload, ;
            pl_Silent, ;
            pc_Compid

#include global.h
#include events.h

LOCAL ll_Return, ;
      lc_DbfTable, ;
      lc_SqlTable, ;
      lc_SqlDatabase, ;
      lc_SqlSelect, ;
      lc_Notify

PRIVATE lc_Compid

STORE Cc_Null TO lc_Compid, ;
                 lc_DbfTable, ;
                 lc_SqlTable, ;
                 lc_SqlDatabase, ;
                 lc_SqlSelect, ;
                 lc_Notify


#IF 0
LOCAL go_Sql AS sbtmgrsql OF "sbtsql.vcx" 
LOCAL lo_Table AS sbtcmpsql OF "sbtsql.vcx" 
#ENDIF

ll_Return = .t.

IF ll_Return AND TYPE("go_Sql.BaseClass") <> "C"
  = MESSAGEBOX("You must have go_Sql setup. Run DO tools\sqltest.")
  ll_Return = .f.
ENDIF

IF ll_Return AND ;
  go_Sql.sc_SqlTypeMain <> "S"
  = MESSAGEBOX("Your pro.ini is not Set for SQL/DB2. " + ;
     CHR(13) + "Fix this before running the tool")
  ll_Return = .f.
ENDIF

IF ll_Return AND ;
  EMPTY(pc_TableToUpload)
  = MESSAGEBOX("Please pass the name of the table to upload.")
  ll_Return = .f.
ENDIF

IF ll_Return
  lc_DbfTable = DEFAULTEXT(pc_TableToUpload, "DBF")

  IF NOT FILE(lc_DbfTable)
    = MESSAGEBOX("Source VFP table not found " + ;
      lc_DbfTable + ".")
    ll_Return = .f.
  ENDIF

ENDIF

IF ll_Return AND go_Sql.sc_Sqltype = "SS"
  *-- Find SQL Server full table name
  lc_SqlTable = JUSTSTEM(ALLTRIM(pc_TableToUpload))
  
  IF UPPER(LEFT(lc_SqlTable, 2)) = "SY"
    *-- Is a system table.
    lc_SqlTable = go_Sql.sc_Sysdbname + lc_SqlTable
  ELSE
  
    IF NOT EMPTY(pc_Compid)
      *-- User has specified a company id.
      lc_Compid = pc_Compid
    ELSE
      lc_Compid = RIGHT(lc_SqlTable, 2)
    ENDIF
    
    TEXT TO lc_SqlSelect TEXTMERGE NOSHOW
      SELECT dbname FROM <<go_Sql.sc_sysdbname>>syccomp AS a_syccomp
        WHERE a_syccomp->compid = ?lc_compid
    ENDTEXT
      
    go_Sql.m_SqlSelect(STRTRAN(lc_SqlSelect, Cc_OsEol, ""),"CURSOR","ac_syccomp")
    
    IF go_Sql.cmpac_Syccomp.m_Reccount() > 0
      *-- Add the database name for the table and remove company #.
      lc_SqlTable = ac_syccomp->dbname + ".." + LEFT(lc_SqlTable, LEN(lc_SqlTable) - 2)
    ELSE
      = MESSAGEBOX("Company " + lc_Compid + " not found in backend syccomp.")
      ll_Return = .f.
    ENDIF

  ENDIF

ENDIF ll_Return AND go_Sql.sc_Sqltype = "SS"

IF ll_Return AND go_Sql.sc_Sqltype = "SD"
  *-- Find DB2 full table name
  lc_SqlTable = JUSTSTEM(ALLTRIM(pc_TableToUpload))
  
  IF UPPER(LEFT(lc_SqlTable, 2)) <> "SY"
    *-- Is a company table.
  
    IF NOT EMPTY(pc_Compid)
      *-- User has specified a company id.
      lc_Compid = pc_Compid
    ELSE
      lc_Compid = RIGHT(lc_SqlTable, 2)
    ENDIF
    
    lc_SqlTable = LEFT(lc_SqlTable, LEN(lc_SqlTable) - 2) + lc_Compid
  ENDIF

ENDIF ll_Return AND go_Sql.sc_Sqltype = "SD"

IF ll_Return AND ;
  NOT go_Sql.m_IstableFound(lc_SqlTable, "S")
  = MESSAGEBOX("Table not found in backend " + ;
    lc_SqlTable + ".")
  ll_Return = .f.
ENDIF

IF ll_Return AND ;
  NOT pl_Silent

  *-- Warn user before proceeding.
  ll_Return = MESSAGEBOX("Want to copy contents of " + ;
    lc_DbfTable + " to " + ;
    lc_SqlTable +  "?", 4+32) = 6
ENDIF

IF ll_Return
  *-- All ok

  go_Sql.m_CloseTableAll()

  go_Sql.m_OpenTable("a_SqlTable", lc_SqlTable) 

  lo_Table = go_Sql.cmpA_SqlTable

  *-- Remove old contents
  lc_Notify = SET("Notify")
  SET TALK ON
  
  SET NOTIFY ON
  lo_Table.m_Zap()
  
  *-- Append from FoxPro table
  lo_Table.m_AppendFrom(lc_DbfTable)

  lo_Table.m_CloseTable()

  SET NOTIFY &lc_Notify.
  SET TALK OFF
  
  IF NOT pl_Silent
    WAIT WINDOW "Upload done to " + lc_SqlTable
  ENDIF

ENDIF

RETURN ll_Return
